UpscopeAndroid class
- Inheritance
-
- Object
- PlatformInterface
- UpscopePlatform
- UpscopeAndroid
Constructors
Properties
-
eventStream
→ Stream<
UpscopeEvent> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bindToActivity(
) → Future< void> -
inherited
-
bindToWindow(
) → Future< void> -
inherited
-
connect(
) → Future< void> -
inherited
-
customMessage(
String message) → Future< void> -
inherited
-
declineSession(
) → Future< void> -
inherited
-
disconnect(
) → Future< void> -
inherited
-
getIsConnected(
) → Future< bool> -
inherited
-
getIsConnecting(
) → Future< bool> -
inherited
-
getIsRecording(
) → Future< bool> -
inherited
-
getLookupCode(
) → Future< String?> -
inherited
-
getShortId(
) → Future< String?> -
inherited
-
getUniqueConnectionId(
) → Future< String?> -
inherited
-
getWatchLink(
) → Future< String?> -
inherited
-
initialize(
UpscopeConfiguration config) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerFlutterRedactionMiddleware(
) → Future< void> -
inherited
-
registerFullScreenRedactionForTesting(
) → Future< void> -
inherited
-
requestScreenCapturePermission(
) → Future< void> -
inherited
-
reset(
) → Future< void> -
inherited
-
stopSession(
) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateConnection(
{Map< String, dynamic> ? metadata}) → Future<void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void