UpscopeConfiguration class

Annotations

Constructors

UpscopeConfiguration({bool? beta, String? teamDomain, bool? showUpscopeLink, bool? showTerminateButton, bool? enableLookupCodeOnShake, String? lookupCodeKeyTitle, String? lookupCodeKeyMessage, bool? requireAuthorizationForSession, String? authorizationPromptTitle, String? authorizationPromptMessage, String? endOfScreenshareMessage, String? translationsYes, String? translationsNo, String? translationsOk, String? translationsStopSession, bool? autoconnect, String? region, String? defaultRegion})
const
UpscopeConfiguration.fromMap(Map<String, dynamic> map)
factory

Properties

authorizationPromptMessage → String?
final
authorizationPromptTitle → String?
final
autoconnect → bool?
final
beta → bool?
final
defaultRegion → String?
final
enableLookupCodeOnShake → bool?
final
endOfScreenshareMessage → String?
final
hashCode → int
The hash code for this object.
no setteroverride
lookupCodeKeyMessage → String?
final
lookupCodeKeyTitle → String?
final
region → String?
final
requireAuthorizationForSession → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTerminateButton → bool?
final
final
teamDomain → String?
final
translationsNo → String?
final
translationsOk → String?
final
translationsStopSession → String?
final
translationsYes → String?
final

Methods

copyWith({bool? beta, String? teamDomain, bool? showUpscopeLink, bool? showTerminateButton, bool? enableLookupCodeOnShake, String? lookupCodeKeyTitle, String? lookupCodeKeyMessage, bool? requireAuthorizationForSession, String? authorizationPromptTitle, String? authorizationPromptMessage, String? endOfScreenshareMessage, String? translationsYes, String? translationsNo, String? translationsOk, String? translationsStopSession, bool? autoconnect, String? region, String? defaultRegion}) → UpscopeConfiguration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override